<?php

App::uses('BuzzEmailsAppController', 'BuzzEmails.Controller');

class EmailsController extends BuzzEmailsAppController {

/**
 * Supported admin actions
 *
 * @var array
 */
	public $adminActions = array(
		'admin_index',
		'admin_edit'
	);

	public $components = array(
		'BuzzTranslate.Translation' => array(
			'fields' => array(
				'subject',
				'content'
			)
		)
	);

	public function admin_edit($id = null) {
		parent::admin_edit($id);
		$this->Translation->adminTranslationFormFields();
		return;
	}

/**
 * Admin index paginate
 *
 * @return array
 */
	protected function _adminIndexPaginate() {
		$conditions = $this->_processFilter();

		$paginate = array(
			'conditions' => $conditions,
			'contain' => array(
				'EmailGroup'
			)
		);

		return $paginate;
	}

	protected function _adminFormFields() {
		$fields = parent::_adminFormFields();

		$fields['Email.name']['displayonly'] = 'displayonly';
		$fields['Email.required_tokens']['displayonly'] = 'displayonly';
		$fields['Email.optional_tokens']['displayonly'] = 'displayonly';

		return $fields;
	}

/**
 * Admin index columns
 *
 * @return array
 */
	protected function _adminIndexColumns() {
		$Email = $this->{$this->modelClass};

		$columns = parent::_adminIndexColumns();

		// Remove modified columns.
		unset($columns['Email.created']);

		$newColumns = array(
			'EmailGroup.name' => array(
				'label' => __d('buzz_emails', 'Group'),
				'type' => 'string'
			)
		);

		return ArrayUtil::addAfter($columns, 'Email.subject', $newColumns);
	}

/**
 * Defines a whitelist of columns to be displayed on the admin index.
 *
 * @return array whitelisted columns
 */
	protected function _adminIndexColumnsWhitelist() {
		$Email = $this->{$this->modelClass};
		$alias = $Email->alias;

		$columns = parent::_adminIndexColumnsWhitelist();
		$columns[] = $alias . '.subject';

		return $columns;
	}

	protected function _adminIndexToolbar() {
		return [];
	}

	protected function _adminFormToolbar($id = null) {
		return [];
	}

/**
 * Used to populate form drop down selects
 *
 * @return void
 */
	protected function _adminPopulateLookups() {
		$this->set('emailGroups', $this->Email->EmailGroup->find('list'));
		return;
	}

/**
 * Filters
 *
 * @return array
 */
	protected function _adminFilterFields() {
		$filters = parent::_adminFilterFields();

		unset($filters['Email.created']);
		unset($filters['Email.modified']);

		$newFilters = array(
			'Email.subject' => array(
				'label' => __d('buzz_emails', 'Subject'),
				'type' => 'string',
				'compare' => array('Email.subject LIKE' => "%%%s%%")
			),
			'Email.email_group_id' => array(
				'label' => __d('buzz_emails', 'Group'),
				'type' => 'select',
				'compare' => array('Email.email_group_id' => "%s")
			)
		);

		return ArrayUtil::addAfter($filters, 'Email.name', $newFilters);
	}

}
